@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import logging
 from collections.abc import Sequence
 from dataclasses import asdict
 from typing import TYPE_CHECKING
@@ -13,6 +14,8 @@ from ..smartmodule import SmartModule, allow_update_after
 if TYPE_CHECKING:
     from ..smartdevice import SmartDevice
 
+_LOGGER = logging.getLogger(__name__)
+
 
 class LightPreset(SmartModule, LightPresetInterface):
     """Implementation of light presets."""
@@ -39,6 +42,14 @@ class LightPreset(SmartModule, LightPresetInterface):
         state_key = "states" if not self._state_in_sysinfo else self.SYS_INFO_STATE_KEY
         if preset_states := self.data.get(state_key):
             for preset_state in preset_states:
+                if "brightness" not in preset_state:
+                    # Some devices can store effects as a preset. These will be ignored
+                    # and handled in the effects module
+                    if "lighting_effect" not in preset_state:
+                        _LOGGER.info(
+                            "Unexpected keys %s in preset", list(preset_state.keys())
+                        )
+                    continue
                 color_temp = preset_state.get("color_temp")
                 hue = preset_state.get("hue")
                 saturation = preset_state.get("saturation")
@@ -142,6 +153,9 @@ class LightPreset(SmartModule, LightPresetInterface):
         """Query to execute during the update cycle."""
         if self._state_in_sysinfo:  # Child lights can have states in the child info
             return {}
+        if self.supported_version < 3:
+            return {self.QUERY_GETTER_NAME: None}
+
         return {self.QUERY_GETTER_NAME: {"start_index": 0}}
 
     async def _check_supported(self):
